@@ -10,6 +10,8 @@ from urllib.parse import urlsplit, urljoin
 import os
 from typing import Callable
 import jwt
+from urllib.parse import urlparse
+
 
 os.environ['OAUTHLIB_INSECURE_TRANSPORT'] = "1"
 AUTH_URL = 'https://login.salesforce.com'
@@ -22,7 +24,7 @@ def login(client_id: str = None, client_secret: str = None, token: dict = {},
           token_updater: Callable = lambda x: True, callback_port: int = 8000,
           force_login: bool = False, scope: str = 'refresh_token openid web full',
           auth_url: str = AUTH_URL, redirect_url: str = None, private_key: str = None,
-          private_key_filename: str = None, username: str = None):
+          private_key_filename: str = None, username: str = None, **kwargs):
     auth_code_url = urljoin(auth_url, AUTH_REL_URL)
     token_url = urljoin(auth_url, TOKEN_REL_URL)
     redirect_url = redirect_url or f"http://localhost:{callback_port}/callback"
@@ -143,6 +145,25 @@ class SalesforceJWTClient(BackendApplicationClient):
         return uri, headers, body
 
 
+def sfdx_auth_url_to_dict(url):
+    p_url = urlparse(url)
+    if p_url.scheme == 'force':
+        i_url = f"https://{p_url.hostname}"
+        return {
+            "client_id": p_url.username,
+            "client_secret": p_url.password.split(':')[0],
+            "token": {
+                "refresh_token": p_url.password.split(':')[1],
+                "instance_url": i_url,
+                "access_token": 'REFRESH_ME',
+                "expires_at": int(datetime.now().timestamp())
+
+            },
+            "auth_url": i_url
+
+        }
+
+
 class SalesforceOAuth2Session(OAuth2Session):
     def __init__(self, instance_url=None, api_root=None, *args, **kwargs):
         super(SalesforceOAuth2Session, self).__init__(*args, **kwargs)
